#include <iostream>
#include <string>
using namespace std;

const int max_id_num = 20;

class resurs_stat {
  public:
    // Ukupni, tekuci i maksimalni broj entiteta u resursu
    int broj, tek_broj, max_broj;
    // Ukupno vreme za koje je resur bio zauzet
    double ukupno_vreme;
    // Vreme za koje se entitet zadrzava u resursu
    double povrsina_cekanja;
    // Poslednji trenutak promene stanja entiteta u resurs
    double vreme_promene;
    // Ukupno vreme simulacije
    double vreme_sim;
    // Polje rednih brojeva entiteta koji se nalaze u resursu
    int id[max_id_num];
    // Vremenski trenutak promene stanja resursa od strane entiteta 
    double vreme[max_id_num];
  private:
    // Broj entiteta u polju id i polju vreme
    int broj_id;
  public:
    resurs_stat(): broj(0),tek_broj(0),max_broj(0),
                   ukupno_vreme(0),povrsina_cekanja(0),
                   vreme_promene(0), broj_id(0) {}
    // Dodajemo redni broj entiteta u polje id
    void dodaj_id(int novi_id,double novo_vreme) {
      if(broj_id<max_id_num) {
        id[broj_id] = novi_id;
        vreme[broj_id] = novo_vreme;
        broj_id++;
      }
      else {
        cerr << "Greska dodaj id" << endl;
        exit(1);
      }
    }
    // Nalazimo redni broj entiteta u polju id
    int nadji_id(int trazi_id) {
      int i;
      for(i=0; i<broj_id; i++) 
        if(id[i]==trazi_id)
          break;
      return i;
    }
    // Uklanjamo redni broj i tekuce vreme entiteta iz polja id i vreme sa pozicije pos
    void ukloni_id(int pos) {
      for(int i=pos+1; i<broj_id; i++) {
        id[i-1] = id[i];
        vreme[i-1] = vreme[i]; 
      }
      broj_id--;
    }
    void vreme_simulacije(double vs) { vreme_sim = vs; }
    double srednje_vreme() {
      return ukupno_vreme/(broj-tek_broj);
    }
    double srednji_broj_entiteta() {
      return povrsina_cekanja/vreme_sim;
    }
    double iskoriscenost(int broj_kanala) {
      return srednji_broj_entiteta()/broj_kanala;
    }
};
// Klasa statistika reda cekanja
class fifo_red_stat: public resurs_stat {
  public:
    // Broj klijenata koji nisu cekali
    int broj_bezcekanja;
  public:
    fifo_red_stat():resurs_stat(),broj_bezcekanja(0) {}
    double procenat_entiteta_bez_zadrzavanja() {
      return (100.0*broj_bezcekanja)/broj;
    }
    double srednji_broj_entiteta_bez_zadrzavanja() {
      return ukupno_vreme/(broj-tek_broj-broj_bezcekanja);
    }
};

void print_statistike_reda_cekanja(fifo_red_stat& red,const char* opis) {
  // Statistike reda cekanja
  cout << "STATISTIKE REDA CEKANJA - " << opis << endl;
  cout << "Broj entiteta koji je usao u red cekanja: " << red.broj << endl;
  cout << "Preostali broj entiteta u redu cekanja: " << red.tek_broj << endl;
  cout << "Maksimalni broj entiteta u redu: " << red.max_broj << endl;
  cout << "Srednje vreme cekanja u redu: " << red.srednje_vreme() << endl;
  cout << "Srednji broj entiteta u redu: " << red.srednji_broj_entiteta() << endl;
  cout << "Broj entiteta koji je prosao kroz red bez zadrzavanja: " << red.broj_bezcekanja << endl;
  cout << "Procenat ulaza bez zadrzavanja: " << red.procenat_entiteta_bez_zadrzavanja() << endl;
  cout << "Srednje vreme cekanja u redu (iskljuc. ent. koji se nisu zadrzali): " << red.srednji_broj_entiteta_bez_zadrzavanja() << endl;
  cout << endl;
}
void print_statistike_resursa(resurs_stat& salt,int n,const char* opis) {
  // Statistike resursa
  cout << "STATISTIKE RESURSA - " << opis << endl;
  cout << "Broj entiteta koji je usao u resurs: " << salt.broj << endl;
  cout << "Preostali broj entiteta u resursu: " << salt.tek_broj << endl;
  cout << "Maksimalni broj zauzetih kanala opsluge: " << salt.max_broj << endl;
  cout << "Srednje vreme opsluge: " << salt.srednje_vreme() << endl;
  cout << "Srednji broj zauzetih kanala: " << salt.srednji_broj_entiteta() << endl;
  cout << "Iskoriscenost: " << salt.iskoriscenost(n) << endl;
  cout << endl;
}
int main() {
  int pos, posn, idv;
  string str, tip, id, vreme;
  char line[1024];
  resurs_stat salt1, salt2;
  fifo_red_stat red1, red2;
  double vremev, vreme_sim = 0.0,
         vreme_u_redu, vreme_u_res;
  // Ucitavamo podatke iz izvestaja sve dok ne dodjemo do kraja datoteke
  while(cin.good()) {
    // Ucitavamo liniju iz izvestaja
    cin.getline(line,1024);
    // Dodlejujemo liniju stringu
    str = line;
    // Izdvajamo tip obavestenja
    posn = str.find_first_of(',');
    tip = str.substr(0,posn);
    pos = posn;
    // Izdvajamo vrednost rednog broja entiteta
    posn = str.find_first_of(',',pos+1);
    id = str.substr(pos+1,posn-pos-1);
    pos = posn;
    // Izdvajamo vremenski trenutak
    vreme = str.substr(pos+1);
    // Prevodimo id i vremenski trenutak u broj
    idv = atoi(id.c_str());
    vremev = atof(vreme.c_str());
    // Proveravamo tip obavestenja
    if(!tip.compare("ured_uni")) {
      // Broj entiteta koji su usli u red cekanja
      red1.broj++;
      // Uvecavamo ukupno cekanje u redu
      red1.povrsina_cekanja += red1.tek_broj*(vremev-red1.vreme_promene);
      // Pamtimo trenutak dolaska entiteta u red
      red1.vreme_promene = vremev;
      //  Uvecavamo broj entiteta u redu
      red1.tek_broj++;
      // Ukoliko je tekuci broj klijenata u redu  veci od maksimalnog
      // tekuci broj postaje maksimalni broj
      if(red1.tek_broj>red1.max_broj)
        red1.max_broj = red1.tek_broj;
      // Pamtimo redni broj i trenutak ulaska entiteta u redu
      red1.dodaj_id(idv,vremev);
    }
    else if(!tip.compare("izred_uni")) {
      // Nalazimo poziciju entiteta u redu
      int n = red1.nadji_id(idv);
      // Izracunavamo vreme cekanja u redu
      vreme_u_redu = vremev-red1.vreme[n];
      // Ukupno vreme koje su entiteti proveli u redu
      red1.ukupno_vreme += vreme_u_redu;
      // 
      red1.povrsina_cekanja += red1.tek_broj*(vremev-red1.vreme_promene);
      // Ukoliko je vreme koje je entitet proveo u redu 0
      if(vreme_u_redu==0.0) 
        // Uvecavamo broj entiteta koji nisu cekali u redu
        red1.broj_bezcekanja++;
      // Uklanjamo redni broj entiteta sa pozicije n
      red1.ukloni_id(n);
      //  Umanjujemo tekuci broj entiteta u redu
      red1.tek_broj--;
    }
    else if(!tip.compare("ured_pak")) {
      // Broj entiteta koji su usli u red cekanja
      red2.broj++;
      // Uvecavamo ukupno cekanje u redu
      red2.povrsina_cekanja += red2.tek_broj*(vremev-red2.vreme_promene);
      // Pamtimo trenutak dolaska entiteta u red
      red2.vreme_promene = vremev;
      //  Uvecavamo broj entiteta u redu
      red2.tek_broj++;
      // Ukoliko je tekuci broj klijenata u redu  veci od maksimalnog
      // tekuci broj postaje maksimalni broj
      if(red2.tek_broj>red2.max_broj)
        red2.max_broj = red2.tek_broj;
      // Pamtimo redni broj i trenutak ulaska entiteta u redu
      red2.dodaj_id(idv,vremev);
    }
    else if(!tip.compare("izred_pak")) {
      // Nalazimo poziciju entiteta u redu
      int n = red2.nadji_id(idv);
      // Izracunavamo vreme cekanja u redu
      vreme_u_redu = vremev-red2.vreme[n];
      // Ukupno vreme koje su entiteti proveli u redu
      red2.ukupno_vreme += vreme_u_redu;
      // 
      red2.povrsina_cekanja += red2.tek_broj*(vremev-red2.vreme_promene);
      // Ukoliko je vreme koje je entitet proveo u redu 0
      if(vreme_u_redu==0.0) 
        // Uvecavamo broj entiteta koji nisu cekali u redu
        red2.broj_bezcekanja++;
      // Uklanjamo redni broj entiteta sa pozicije n
      red2.ukloni_id(n);
      //  Umanjujemo tekuci broj entiteta u redu
      red2.tek_broj--;
    }
    else if(!tip.compare("usal_uni")){
      // Uvecamo broj entiteta koji su usli resurs
      salt1.broj++;
      //
      salt1.povrsina_cekanja += salt1.tek_broj*(vremev-salt1.vreme_promene);
      // Pamtimo trenutak poslednje promene broja zauzetih mesta
      salt1.vreme_promene = vremev;
      //  Uvecavamo tekuci broj zauzetih mesta u salteru
      salt1.tek_broj++;
      // Ukoliko je tekuci broj zauzetih mesta veci od maksimalnog
      // tekuci broj postaje maksimalni broj
      if(salt1.tek_broj>salt1.max_broj)
        salt1.max_broj = salt1.tek_broj;
      // Pamtimo redni broj entiteta u resursu i trenutak ulaska entiteta u resurs
      salt1.dodaj_id(idv,vremev);
    }
    else if(!tip.compare("izsal_uni")) {
      // Nalazimo poziciju entiteta u resursu
      int n = salt1.nadji_id(idv);
      // Vreme koje entitet provodi u resursu
      vreme_u_res = vremev-salt1.vreme[n];
      // Ukupno vreme koje su entiteti proveli u salteru
      salt1.ukupno_vreme += vreme_u_res;
      //
      salt1.povrsina_cekanja += salt1.tek_broj*(vremev-salt1.vreme_promene);
      // Pamtimo vreme ulaska entiteta u resurs
      salt1.vreme_promene = vremev;
      // Uklanjamo redni broj entiteta sa pozicije n
      salt1.ukloni_id(n);
      //  Umanjujemo tekuci broj entiteta u resursu
      salt1.tek_broj--;
    }
    else if(!tip.compare("usal_pak")) {
      // Uvecamo broj entiteta koji su usli resurs
      salt2.broj++;
      //
      salt2.povrsina_cekanja += salt2.tek_broj*(vremev-salt2.vreme_promene);
      // Pamtimo trenutak poslednje promene broja zauzetih mesta
      salt2.vreme_promene = vremev;
      //  Uvecavamo tekuci broj zauzetih mesta u salteru
      salt2.tek_broj++;
      // Ukoliko je tekuci broj zauzetih mesta veci od maksimalnog
      // tekuci broj postaje maksimalni broj
      if(salt2.tek_broj>salt2.max_broj)
        salt2.max_broj = salt2.tek_broj;
      // Pamtimo redni broj entiteta u resursu i trenutak ulaska entiteta u resurs
      salt2.dodaj_id(idv,vremev);
    }
    else if(!tip.compare("izsal_pak")) {
      // Nalazimo poziciju entiteta u resursu
      int n = salt2.nadji_id(idv);
      // Vreme koje entitet provodi u resursu
      vreme_u_res = vremev-salt2.vreme[n];
      // Ukupno vreme koje su entiteti proveli u salteru
      salt2.ukupno_vreme += vreme_u_res;
      //
      salt2.povrsina_cekanja += salt2.tek_broj*(vremev-salt2.vreme_promene);
      // Pamtimo vreme ulaska entiteta u resurs
      salt2.vreme_promene = vremev;
      // Uklanjamo redni broj entiteta sa pozicije n
      salt2.ukloni_id(n);
      //  Umanjujemo tekuci broj entiteta u resursu
      salt2.tek_broj--;
    }
    else if(!tip.compare("vsim")) {
      //  Pamtimo vreme simulacije
      vreme_sim = vremev;
      // Postavljamo vreme simulacije
      red1.vreme_simulacije(vremev);
      red2.vreme_simulacije(vremev);
      salt1.vreme_simulacije(vremev);
      salt2.vreme_simulacije(vremev);
      //
      red1.dodaj_id(idv,vremev);
      red2.dodaj_id(idv,vremev);
      salt1.dodaj_id(idv,vremev);
      salt2.dodaj_id(idv,vremev);
      //
      salt1.povrsina_cekanja += salt1.tek_broj*(vremev-salt1.vreme_promene);
      salt2.povrsina_cekanja += salt2.tek_broj*(vremev-salt2.vreme_promene);
      red1.povrsina_cekanja += red1.tek_broj*(vremev-red1.vreme_promene);
      red2.povrsina_cekanja += red2.tek_broj*(vremev-red2.vreme_promene);
    }
  }
  // Podesavamo preciznost izlaznih rezulata
  cout.precision(3);
  cout.setf(ios_base::fixed);
  // ISPISUJEMO STATISTIKE
  // Ispisujemo vreme simulacije
  cout << "Vreme simulacije: " << vreme_sim << endl;
  cout << endl;
  // Statistike reda cekanja
  print_statistike_reda_cekanja(red1,"UNIVERZALNI");
  print_statistike_reda_cekanja(red2,"PAKETSKI");
  // Statistike resursa
  print_statistike_resursa(salt1,2,"UNIVERZALNI");
  print_statistike_resursa(salt2,1,"PAKETSKI");
  return 0;
}
